@@ -17,6 +17,9 @@ class DoubleMLIIVM(DoubleML):
     ml_g : estimator implementing ``fit()`` and ``predict()``
         A machine learner implementing ``fit()`` and ``predict()`` methods (e.g.
         :py:class:`sklearn.ensemble.RandomForestRegressor`) for the nuisance function :math:`g_0(Z,X) = E[Y|X,Z]`.
+        For a binary outcome variable :math:`Y` (with values 0 and 1), a classifier implementing ``fit()`` and
+        ``predict_proba()`` can also be specified. If :py:func:`sklearn.base.is_classifier` returns ``True``,
+        ``predict_proba()`` is used otherwise ``predict()``.
 
     ml_m : classifier implementing ``fit()`` and ``predict_proba()``
         A machine learner implementing ``fit()`` and ``predict_proba()`` methods (e.g.
@@ -137,11 +140,18 @@ class DoubleMLIIVM(DoubleML):
 
         self._check_data(self._dml_data)
         self._check_score(self.score)
-        _ = self._check_learner(ml_g, 'ml_g', regressor=True, classifier=False)
+        ml_g_is_classifier = self._check_learner(ml_g, 'ml_g', regressor=True, classifier=True)
         _ = self._check_learner(ml_m, 'ml_m', regressor=False, classifier=True)
         _ = self._check_learner(ml_r, 'ml_r', regressor=False, classifier=True)
         self._learner = {'ml_g': ml_g, 'ml_m': ml_m, 'ml_r': ml_r}
-        self._predict_method = {'ml_g': 'predict', 'ml_m': 'predict_proba', 'ml_r': 'predict_proba'}
+        if ml_g_is_classifier:
+            if obj_dml_data.binary_outcome:
+                self._predict_method = {'ml_g': 'predict_proba', 'ml_m': 'predict_proba', 'ml_r': 'predict_proba'}
+            else:
+                raise ValueError(f'The ml_g learner {str(ml_g)} was identified as classifier '
+                                 'but the outcome variable is not binary with values 0 and 1.')
+        else:
+            self._predict_method = {'ml_g': 'predict', 'ml_m': 'predict_proba', 'ml_r': 'predict_proba'}
         self._initialize_ml_nuisance_params()
 
         valid_trimming_rule = ['truncate']
@@ -210,7 +220,7 @@ class DoubleMLIIVM(DoubleML):
             raise ValueError(err_msg)
         return
 
-    def _nuisance_est(self, smpls, n_jobs_cv):
+    def _nuisance_est(self, smpls, n_jobs_cv, return_models=False):
         x, y = check_X_y(self._dml_data.x, self._dml_data.y,
                          force_all_finite=False)
         x, z = check_X_y(x, np.ravel(self._dml_data.z),
@@ -223,38 +233,70 @@ class DoubleMLIIVM(DoubleML):
 
         # nuisance g
         g_hat0 = _dml_cv_predict(self._learner['ml_g'], x, y, smpls=smpls_z0, n_jobs=n_jobs_cv,
-                                 est_params=self._get_params('ml_g0'), method=self._predict_method['ml_g'])
-        _check_finite_predictions(g_hat0, self._learner['ml_g'], 'ml_g', smpls)
+                                 est_params=self._get_params('ml_g0'), method=self._predict_method['ml_g'],
+                                 return_models=return_models)
+        _check_finite_predictions(g_hat0['preds'], self._learner['ml_g'], 'ml_g', smpls)
+
+        if self._dml_data.binary_outcome:
+            binary_preds = (type_of_target(g_hat0['preds']) == 'binary')
+            zero_one_preds = np.all((np.power(g_hat0['preds'], 2) - g_hat0['preds']) == 0)
+            if binary_preds & zero_one_preds:
+                raise ValueError(f'For the binary outcome variable {self._dml_data.y_col}, '
+                                 f'predictions obtained with the ml_g learner {str(self._learner["ml_g"])} are also '
+                                 'observed to be binary with values 0 and 1. Make sure that for classifiers '
+                                 'probabilities and not labels are predicted.')
+
         g_hat1 = _dml_cv_predict(self._learner['ml_g'], x, y, smpls=smpls_z1, n_jobs=n_jobs_cv,
-                                 est_params=self._get_params('ml_g1'), method=self._predict_method['ml_g'])
-        _check_finite_predictions(g_hat1, self._learner['ml_g'], 'ml_g', smpls)
+                                 est_params=self._get_params('ml_g1'), method=self._predict_method['ml_g'],
+                                 return_models=return_models)
+        _check_finite_predictions(g_hat1['preds'], self._learner['ml_g'], 'ml_g', smpls)
+
+        if self._dml_data.binary_outcome:
+            binary_preds = (type_of_target(g_hat1['preds']) == 'binary')
+            zero_one_preds = np.all((np.power(g_hat1['preds'], 2) - g_hat1['preds']) == 0)
+            if binary_preds & zero_one_preds:
+                raise ValueError(f'For the binary outcome variable {self._dml_data.y_col}, '
+                                 f'predictions obtained with the ml_g learner {str(self._learner["ml_g"])} are also '
+                                 'observed to be binary with values 0 and 1. Make sure that for classifiers '
+                                 'probabilities and not labels are predicted.')
 
         # nuisance m
         m_hat = _dml_cv_predict(self._learner['ml_m'], x, z, smpls=smpls, n_jobs=n_jobs_cv,
-                                est_params=self._get_params('ml_m'), method=self._predict_method['ml_m'])
-        _check_finite_predictions(m_hat, self._learner['ml_m'], 'ml_m', smpls)
+                                est_params=self._get_params('ml_m'), method=self._predict_method['ml_m'],
+                                return_models=return_models)
+        _check_finite_predictions(m_hat['preds'], self._learner['ml_m'], 'ml_m', smpls)
 
         # nuisance r
         if self.subgroups['always_takers']:
             r_hat0 = _dml_cv_predict(self._learner['ml_r'], x, d, smpls=smpls_z0, n_jobs=n_jobs_cv,
-                                     est_params=self._get_params('ml_r0'), method=self._predict_method['ml_r'])
+                                     est_params=self._get_params('ml_r0'), method=self._predict_method['ml_r'],
+                                     return_models=return_models)
         else:
-            r_hat0 = np.zeros_like(d)
-        _check_finite_predictions(r_hat0, self._learner['ml_r'], 'ml_r', smpls)
+            r_hat0 = {'preds': np.zeros_like(d), 'models': None}
+        _check_finite_predictions(r_hat0['preds'], self._learner['ml_r'], 'ml_r', smpls)
 
         if self.subgroups['never_takers']:
             r_hat1 = _dml_cv_predict(self._learner['ml_r'], x, d, smpls=smpls_z1, n_jobs=n_jobs_cv,
-                                     est_params=self._get_params('ml_r1'), method=self._predict_method['ml_r'])
+                                     est_params=self._get_params('ml_r1'), method=self._predict_method['ml_r'],
+                                     return_models=return_models)
         else:
-            r_hat1 = np.ones_like(d)
-        _check_finite_predictions(r_hat1, self._learner['ml_r'], 'ml_r', smpls)
+            r_hat1 = {'preds': np.ones_like(d), 'models': None}
+        _check_finite_predictions(r_hat1['preds'], self._learner['ml_r'], 'ml_r', smpls)
 
-        psi_a, psi_b = self._score_elements(y, z, d, g_hat0, g_hat1, m_hat, r_hat0, r_hat1, smpls)
-        preds = {'ml_g0': g_hat0,
-                 'ml_g1': g_hat1,
-                 'ml_m': m_hat,
-                 'ml_r0': r_hat0,
-                 'ml_r1': r_hat1}
+        psi_a, psi_b = self._score_elements(y, z, d,
+                                            g_hat0['preds'], g_hat1['preds'], m_hat['preds'],
+                                            r_hat0['preds'], r_hat1['preds'], smpls)
+        preds = {'predictions': {'ml_g0': g_hat0['preds'],
+                                 'ml_g1': g_hat1['preds'],
+                                 'ml_m': m_hat['preds'],
+                                 'ml_r0': r_hat0['preds'],
+                                 'ml_r1': r_hat1['preds']},
+                 'models': {'ml_g0': g_hat0['models'],
+                            'ml_g1': g_hat1['models'],
+                            'ml_m': m_hat['models'],
+                            'ml_r0': r_hat0['models'],
+                            'ml_r1': r_hat1['models']}
+                 }
 
         return psi_a, psi_b, preds
 
@@ -279,7 +321,9 @@ class DoubleMLIIVM(DoubleML):
                         - np.divide(np.multiply(1.0-z, w_hat0), 1.0 - m_hat))
         else:
             assert callable(self.score)
-            psi_a, psi_b = self.score(y, z, d, g_hat0, g_hat1, m_hat, r_hat0, r_hat1, smpls)
+            psi_a, psi_b = self.score(y=y, z=z, d=d,
+                                      g_hat0=g_hat0, g_hat1=g_hat1, m_hat=m_hat, r_hat0=r_hat0, r_hat1=r_hat1,
+                                      smpls=smpls)
 
         return psi_a, psi_b
 
