@@ -6,37 +6,37 @@ from ._utils import fit_predict, tune_grid_search
 
 
 def fit_pliv_partial_x(y, x, d, z,
-                       learner_g, learner_m, learner_r, all_smpls, dml_procedure, score,
-                       n_rep=1, g_params=None, m_params=None, r_params=None):
+                       learner_l, learner_m, learner_r, all_smpls, dml_procedure, score,
+                       n_rep=1, l_params=None, m_params=None, r_params=None):
     n_obs = len(y)
 
     thetas = np.zeros(n_rep)
     ses = np.zeros(n_rep)
-    all_g_hat = list()
+    all_l_hat = list()
     all_m_hat = list()
     all_r_hat = list()
     for i_rep in range(n_rep):
         smpls = all_smpls[i_rep]
 
-        g_hat, m_hat, r_hat = fit_nuisance_pliv_partial_x(y, x, d, z,
-                                                          learner_g, learner_m, learner_r,
+        l_hat, m_hat, r_hat = fit_nuisance_pliv_partial_x(y, x, d, z,
+                                                          learner_l, learner_m, learner_r,
                                                           smpls,
-                                                          g_params, m_params, r_params)
+                                                          l_params, m_params, r_params)
 
-        all_g_hat.append(g_hat)
+        all_l_hat.append(l_hat)
         all_m_hat.append(m_hat)
         all_r_hat.append(r_hat)
 
         if dml_procedure == 'dml1':
             thetas[i_rep], ses[i_rep] = pliv_partial_x_dml1(y, x, d,
                                                             z,
-                                                            g_hat, m_hat, r_hat,
+                                                            l_hat, m_hat, r_hat,
                                                             smpls, score)
         else:
             assert dml_procedure == 'dml2'
             thetas[i_rep], ses[i_rep] = pliv_partial_x_dml2(y, x, d,
                                                             z,
-                                                            g_hat, m_hat, r_hat,
+                                                            l_hat, m_hat, r_hat,
                                                             smpls, score)
 
     theta = np.median(thetas)
@@ -44,14 +44,14 @@ def fit_pliv_partial_x(y, x, d, z,
 
     res = {'theta': theta, 'se': se,
            'thetas': thetas, 'ses': ses,
-           'all_g_hat': all_g_hat, 'all_m_hat': all_m_hat, 'all_r_hat': all_r_hat}
+           'all_l_hat': all_l_hat, 'all_m_hat': all_m_hat, 'all_r_hat': all_r_hat}
 
     return res
 
 
-def fit_nuisance_pliv_partial_x(y, x, d, z, ml_g, ml_m, ml_r, smpls, g_params=None, m_params=None, r_params=None):
+def fit_nuisance_pliv_partial_x(y, x, d, z, ml_l, ml_m, ml_r, smpls, l_params=None, m_params=None, r_params=None):
     assert z.ndim == 2
-    g_hat = fit_predict(y, x, ml_g, g_params, smpls)
+    l_hat = fit_predict(y, x, ml_l, l_params, smpls)
 
     m_hat = list()
     for i_instr in range(z.shape[1]):
@@ -71,12 +71,12 @@ def fit_nuisance_pliv_partial_x(y, x, d, z, ml_g, ml_m, ml_r, smpls, g_params=No
 
     r_hat_tilde = LinearRegression(fit_intercept=True).fit(z - m_hat_array, d - r_hat_array).predict(z - m_hat_array)
 
-    return g_hat, r_hat, r_hat_tilde
+    return l_hat, r_hat, r_hat_tilde
 
 
-def tune_nuisance_pliv_partial_x(y, x, d, z, ml_g, ml_m, ml_r, smpls, n_folds_tune,
-                                 param_grid_g, param_grid_m, param_grid_r):
-    g_tune_res = tune_grid_search(y, x, ml_g, smpls, param_grid_g, n_folds_tune)
+def tune_nuisance_pliv_partial_x(y, x, d, z, ml_l, ml_m, ml_r, smpls, n_folds_tune,
+                                 param_grid_l, param_grid_m, param_grid_r):
+    l_tune_res = tune_grid_search(y, x, ml_l, smpls, param_grid_l, n_folds_tune)
 
     m_tune_res = list()
     for i_instr in range(z.shape[1]):
@@ -84,27 +84,27 @@ def tune_nuisance_pliv_partial_x(y, x, d, z, ml_g, ml_m, ml_r, smpls, n_folds_tu
 
     r_tune_res = tune_grid_search(d, x, ml_r, smpls, param_grid_r, n_folds_tune)
 
-    g_best_params = [xx.best_params_ for xx in g_tune_res]
+    l_best_params = [xx.best_params_ for xx in l_tune_res]
     m_best_params = [[xx.best_params_ for xx in m_tune_res[i_instr]] for i_instr in range(z.shape[1])]
     r_best_params = [xx.best_params_ for xx in r_tune_res]
 
-    return g_best_params, m_best_params, r_best_params
+    return l_best_params, m_best_params, r_best_params
 
 
-def compute_pliv_partial_x_residuals(y, d, g_hat, r_hat, smpls):
+def compute_pliv_partial_x_residuals(y, d, l_hat, r_hat, smpls):
     u_hat = np.full_like(y, np.nan, dtype='float64')
     w_hat = np.full_like(y, np.nan, dtype='float64')
     for idx, (_, test_index) in enumerate(smpls):
-        u_hat[test_index] = y[test_index] - g_hat[idx]
+        u_hat[test_index] = y[test_index] - l_hat[idx]
         w_hat[test_index] = d[test_index] - r_hat[idx]
 
     return u_hat, w_hat
 
 
-def pliv_partial_x_dml1(y, x, d, z, g_hat, r_hat, r_hat_tilde, smpls, score):
+def pliv_partial_x_dml1(y, x, d, z, l_hat, r_hat, r_hat_tilde, smpls, score):
     thetas = np.zeros(len(smpls))
     n_obs = len(y)
-    u_hat, w_hat = compute_pliv_partial_x_residuals(y, d, g_hat, r_hat, smpls)
+    u_hat, w_hat = compute_pliv_partial_x_residuals(y, d, l_hat, r_hat, smpls)
 
     for idx, (_, test_index) in enumerate(smpls):
         thetas[idx] = pliv_partial_x_orth(u_hat[test_index], w_hat[test_index], r_hat_tilde[test_index],
@@ -116,9 +116,9 @@ def pliv_partial_x_dml1(y, x, d, z, g_hat, r_hat, r_hat_tilde, smpls, score):
     return theta_hat, se
 
 
-def pliv_partial_x_dml2(y, x, d, z, g_hat, r_hat, r_hat_tilde, smpls, score):
+def pliv_partial_x_dml2(y, x, d, z, l_hat, r_hat, r_hat_tilde, smpls, score):
     n_obs = len(y)
-    u_hat, w_hat = compute_pliv_partial_x_residuals(y, d, g_hat, r_hat, smpls)
+    u_hat, w_hat = compute_pliv_partial_x_residuals(y, d, l_hat, r_hat, smpls)
     theta_hat = pliv_partial_x_orth(u_hat, w_hat, r_hat_tilde, d, score)
     se = np.sqrt(var_pliv_partial_x(theta_hat, d, u_hat, w_hat, r_hat_tilde, score, n_obs))
 
@@ -140,7 +140,7 @@ def pliv_partial_x_orth(u_hat, w_hat, r_hat_tilde, d, score):
     return res
 
 
-def boot_pliv_partial_x(y, d, z, thetas, ses, all_g_hat, all_m_hat, all_r_hat,
+def boot_pliv_partial_x(y, d, z, thetas, ses, all_l_hat, all_m_hat, all_r_hat,
                         all_smpls, score, bootstrap, n_rep_boot,
                         n_rep=1):
     all_boot_theta = list()
@@ -149,7 +149,7 @@ def boot_pliv_partial_x(y, d, z, thetas, ses, all_g_hat, all_m_hat, all_r_hat,
         n_obs = len(y)
         weights = draw_weights(bootstrap, n_rep_boot, n_obs)
         boot_theta, boot_t_stat = boot_pliv_partial_x_single_split(
-            thetas[i_rep], y, d, z, all_g_hat[i_rep], all_m_hat[i_rep], all_r_hat[i_rep], all_smpls[i_rep],
+            thetas[i_rep], y, d, z, all_l_hat[i_rep], all_m_hat[i_rep], all_r_hat[i_rep], all_smpls[i_rep],
             score, ses[i_rep], weights, n_rep_boot)
         all_boot_theta.append(boot_theta)
         all_boot_t_stat.append(boot_t_stat)
@@ -160,10 +160,10 @@ def boot_pliv_partial_x(y, d, z, thetas, ses, all_g_hat, all_m_hat, all_r_hat,
     return boot_theta, boot_t_stat
 
 
-def boot_pliv_partial_x_single_split(theta, y, d, z, g_hat, r_hat, r_hat_tilde,
+def boot_pliv_partial_x_single_split(theta, y, d, z, l_hat, r_hat, r_hat_tilde,
                                      smpls, score, se, weights, n_rep_boot):
     assert score == 'partialling out'
-    u_hat, w_hat = compute_pliv_partial_x_residuals(y, d, g_hat, r_hat, smpls)
+    u_hat, w_hat = compute_pliv_partial_x_residuals(y, d, l_hat, r_hat, smpls)
 
     J = np.mean(-np.multiply(r_hat_tilde, w_hat))
 
