@@ -2,11 +2,12 @@ import numpy as np
 import pytest
 import math
 
-from sklearn.base import clone
 from sklearn.linear_model import Lasso
 
 import doubleml as dml
 
+from ._utils import _clone
+
 
 @pytest.fixture(scope='module',
                 params=['IV-type', 'partialling out'])
@@ -31,14 +32,18 @@ def dml_plr_fixture(generate_data1, score, dml_procedure):
 
     alpha = 0.05
     learner = Lasso(alpha=alpha)
-    # Set machine learning methods for m & g
-    ml_g = clone(learner)
-    ml_m = clone(learner)
+    # Set machine learning methods for l, m & g
+    ml_l = _clone(learner)
+    ml_m = _clone(learner)
+    if score == 'IV-type':
+        ml_g = _clone(learner)
+    else:
+        ml_g = None
 
     np.random.seed(3141)
     obj_dml_data = dml.DoubleMLData(data, 'y', ['d'])
     dml_plr_obj = dml.DoubleMLPLR(obj_dml_data,
-                                  ml_g, ml_m,
+                                  ml_l, ml_m, ml_g,
                                   n_folds,
                                   score=score,
                                   dml_procedure=dml_procedure)
@@ -47,17 +52,24 @@ def dml_plr_fixture(generate_data1, score, dml_procedure):
 
     np.random.seed(3141)
     learner = Lasso()
-    # Set machine learning methods for m & g
-    ml_g = clone(learner)
-    ml_m = clone(learner)
+    # Set machine learning methods for l, m & g
+    ml_l = _clone(learner)
+    ml_m = _clone(learner)
+    if score == 'IV-type':
+        ml_g = _clone(learner)
+    else:
+        ml_g = None
 
     dml_plr_obj_ext_set_par = dml.DoubleMLPLR(obj_dml_data,
-                                              ml_g, ml_m,
+                                              ml_l, ml_m, ml_g,
                                               n_folds,
                                               score=score,
                                               dml_procedure=dml_procedure)
-    dml_plr_obj_ext_set_par.set_ml_nuisance_params('ml_g', 'd', {'alpha': alpha})
+    dml_plr_obj_ext_set_par.set_ml_nuisance_params('ml_l', 'd', {'alpha': alpha})
     dml_plr_obj_ext_set_par.set_ml_nuisance_params('ml_m', 'd', {'alpha': alpha})
+    if score == 'IV-type':
+        dml_plr_obj_ext_set_par.set_ml_nuisance_params('ml_g', 'd', {'alpha': alpha})
+
     dml_plr_obj_ext_set_par.fit()
 
     res_dict = {'coef': dml_plr_obj.coef,
