@@ -7,15 +7,17 @@ lgr::get_logger("mlr3")$set_threshold("warn")
 on_cran = !identical(Sys.getenv("NOT_CRAN"), "true")
 if (on_cran) {
   test_cases = expand.grid(
-    g_learner = c("regr.rpart", "classif.rpart"),
+    l_learner = c("regr.rpart", "classif.rpart"),
     m_learner = "classif.rpart",
+    g_learner = "regr.rpart",
     dml_procedure = "dml2",
     score = "partialling out",
     stringsAsFactors = FALSE)
 } else {
   test_cases = expand.grid(
-    g_learner = "regr.cv_glmnet",
+    l_learner = c("regr.rpart", "classif.rpart"),
     m_learner = "classif.cv_glmnet",
+    g_learner = "regr.cv_glmnet",
     dml_procedure = c("dml1", "dml2"),
     score = c("IV-type", "partialling out"),
     stringsAsFactors = FALSE)
@@ -27,15 +29,24 @@ patrick::with_parameters_test_that("Unit tests for PLR with classifier for ml_m:
     n_rep_boot = 498
     n_folds = 3
 
-    if (g_learner == "regr.cv_glmnet") {
-      ml_g = mlr3::lrn(g_learner)
-      ml_m = mlr3::lrn(m_learner)
+    ml_l = mlr3::lrn(l_learner)
+    ml_m = mlr3::lrn(m_learner)
+    ml_g = mlr3::lrn(g_learner)
+
+    if (ml_l$task_type == "regr") {
 
       set.seed(3141)
+      if (score == "IV-type") {
+        ml_g = ml_g$clone()
+      } else {
+        ml_g = NULL
+      }
       plr_hat = dml_plr(data_irm$df,
         y = "y", d = "d",
         n_folds = n_folds,
-        ml_g = ml_g$clone(), ml_m = ml_m$clone(),
+        ml_l = ml_l$clone(),
+        ml_m = ml_m$clone(),
+        ml_g = ml_g,
         dml_procedure = dml_procedure, score = score)
       theta = plr_hat$coef
       se = plr_hat$se
@@ -52,10 +63,16 @@ patrick::with_parameters_test_that("Unit tests for PLR with classifier for ml_m:
       pval = plr_hat$pval
 
       set.seed(3141)
+      if (score == "IV-type") {
+        ml_g = ml_g$clone()
+      } else {
+        ml_g = NULL
+      }
       double_mlplr_obj = DoubleMLPLR$new(
         data = data_irm$dml_data,
-        ml_g = ml_g$clone(),
+        ml_l = ml_l$clone(),
         ml_m = ml_m$clone(),
+        ml_g = ml_g,
         dml_procedure = dml_procedure,
         n_folds = n_folds,
         score = score)
@@ -76,12 +93,18 @@ patrick::with_parameters_test_that("Unit tests for PLR with classifier for ml_m:
       expect_equal(pval, pval_obj, tolerance = 1e-8)
       # expect_equal(ci, ci_obj, tolerance = 1e-8)
 
-    } else if (g_learner == "classif.cv_glmnet") {
-      msg = "Invalid learner provided for ml_g: must be of class 'LearnerRegr'"
+    } else if (ml_l$task_type == "classif") {
+      msg = "Invalid learner provided for ml_l: 'learner\\$task_type' must be 'regr'"
+      if (score == "IV-type") {
+        ml_g = ml_g$clone()
+      } else {
+        ml_g = NULL
+      }
       expect_error(DoubleMLPLR$new(
         data = data_irm$dml_data,
-        ml_g = lrn(g_learner),
-        ml_m = lrn(m_learner),
+        ml_l = ml_l$clone(),
+        ml_m = ml_m$clone(),
+        ml_g = ml_g,
         dml_procedure = dml_procedure,
         n_folds = n_folds,
         score = score),
@@ -99,7 +122,7 @@ test_that("Unit tests for exception handling of PLR with classifier for ml_m:",
   dml_data = double_ml_data_from_data_frame(df, y_col = "y", d_cols = "d")
   double_mlplr_obj = DoubleMLPLR$new(
     data = dml_data,
-    ml_g = mlr3::lrn("regr.rpart"),
+    ml_l = mlr3::lrn("regr.rpart"),
     ml_m = mlr3::lrn("classif.rpart"))
   msg = paste(
     "Assertion on 'levels\\(data\\[\\[target\\]\\])' failed: .* set \\{'0','1'\\}")
@@ -112,7 +135,7 @@ test_that("Unit tests for exception handling of PLR with classifier for ml_m:",
   dml_data = double_ml_data_from_data_frame(df, y_col = "y", d_cols = "d")
   double_mlplr_obj = DoubleMLPLR$new(
     data = dml_data,
-    ml_g = mlr3::lrn("regr.rpart"),
+    ml_l = mlr3::lrn("regr.rpart"),
     ml_m = mlr3::lrn("classif.rpart"))
   msg = paste(
     "Assertion on 'levels\\(data\\[\\[target\\]\\])' failed: .* set \\{'0','1'\\}")
